pub struct Any;Expand description
Authorizes any authenticated SPIFFE ID under the active trust-domain policy.
By default (TrustDomainPolicy::AnyInBundleSet), every trust domain in the source
bundle set is accepted.
This is the default authorizer for client and server builders. Production
deployments should usually configure a more specific authorizer, such as
exact or trust_domains.